{% extends "bootstrap/base.html" %}

{% block head %}
  {{ super() }}
  <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
  <script src="{{ url_for('static', filename='js/app.js') }}"></script>
{% endblock %}

{% block title %}
  {{ get_title }}
{% endblock %}

{% block navbar %}
  <link href="static/css/app.css" rel="stylesheet">
  <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
    <div class="container-fluid">
      <div class="navbar-header">
        <a class="navbar-brand" href="/"> {{ get_title }} </a>
      </div>
      <div class="collapse navbar-collapse">
          <ul class="nav navbar-nav">
          <li class="active"><a href="#">Home</a></li>
          <li><a href="#about">About</a></li>
          <li><a href="#contact">Contact</a></li>
        </ul>
      </div><!--/.nav-collapse -->
    </div>
  </div>
{% endblock %}